@@ -1,4 +1,4 @@
-# Copyright 2017 QuantRocket - All Rights Reserved
+# Copyright 2019 QuantRocket - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,8 @@
 import os
 import six
 import requests
+import re
+import uuid
 from .exceptions import ImproperlyConfigured, CannotConnectToHouston
 from quantrocket.cli.utils.output import json_to_cli
 
@@ -76,17 +78,20 @@ class Houston(requests.Session):
     >>> houston = Houston()
     """
 
-    DEFAULT_TIMEOUT = 30
+    DEFAULT_TIMEOUT = 120
 
     def __init__(self):
         super(Houston, self).__init__()
         if "HOUSTON_USERNAME" in os.environ and "HOUSTON_PASSWORD" in os.environ:
             self.auth = (os.environ["HOUSTON_USERNAME"], os.environ["HOUSTON_PASSWORD"])
         self.force_timeout = _get_force_timeout()
+        self._base_url = None
+        self.headers = {}
+        self._set_base_url()
 
     @property
     def base_url(self):
-        if "HOUSTON_URL" not in os.environ:
+        if self._base_url is None:
             raise ImproperlyConfigured("""HOUSTON_URL is not set
 
 --------------------------------------------------------------------------------
@@ -124,7 +129,15 @@ To set the environment variable on Linux, run:
     echo 'export HOUSTON_URL=http://localhost:1969' >> ~/.bashrc
     source ~/.bashrc
 """)
-        return os.environ["HOUSTON_URL"]
+        return self._base_url
+
+    def _set_base_url(self):
+        if "HOUSTON_URL" not in os.environ:
+            return
+
+        self._base_url = os.environ["HOUSTON_URL"]
+        if self._base_url.startswith("https"):
+            self.headers["X-DEV"] = ':'.join(re.findall('..', '%012x' % uuid.getnode()))
 
     def request(self, method, url, *args, **kwargs):
         if url.startswith('/'):
@@ -139,16 +152,17 @@ To set the environment variable on Linux, run:
             elif timeout is None:
                 kwargs["timeout"] = self.DEFAULT_TIMEOUT
 
-        # Move conids from params to data if too long
-        conids = kwargs.get("params", {}).get("conids", None)
-        if conids and isinstance(conids, list) and len(conids) > 10:
-            data = kwargs.get("data", {}) or {}
-            data["conids"] = conids
-            kwargs["params"].pop("conids")
-            kwargs["data"] = data
+        # Move params to data if too long
+        for param_name, param_vals in kwargs.get("params", {}).copy().items():
+            if isinstance(param_vals, list) and len(param_vals) > 50:
+                data = kwargs.get("data", {}) or {}
+                data[param_name] = param_vals
+                kwargs["params"].pop(param_name)
+                kwargs["data"] = data
 
         try:
-            return super(Houston, self).request(method, url, *args, **kwargs)
+            return super(Houston, self).request(
+                method, url, *args, headers=self.headers, **kwargs)
         except requests.ConnectionError as error:
             if "Failed to establish a new connection" not in str(error):
                 raise
